==> deepin-ocr_6.5.0.tar.xz: BUILD/translations/deepin-ocr_ku_IQ.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ku_IQ" version="2.1">
<context>
    <name>MainWidget</name>
    <message>
        <location filename="../src/mainwidget.cpp" line="166"/>
        <source>No text recognized</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="214"/>
        <source>Copy text</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="221"/>
        <source>Save as TXT</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="273"/>
        <location filename="../src/mainwidget.cpp" line="314"/>
        <source>Recognizing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="514"/>
        <source>Copied</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="56"/>
        <source>OCR Tool</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ResultTextView</name>
    <message>
        <location filename="../src/resulttextview.cpp" line="15"/>
        <source>Copy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/resulttextview.cpp" line="17"/>
        <source>Cut</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/resulttextview.cpp" line="20"/>
        <source>Select All</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/resulttextview.cpp" line="22"/>
        <source>Paste</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Widget</name>
    <message>
        <location filename="../src/mainwidget.cpp" line="262"/>
        <source>Tips: The clearer the image is, the more accurate the text is</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> deepin-ocr_6.5.9.tar.xz: BUILD/translations/deepin-ocr_ku_IQ.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ku_IQ">
<context>
    <name>MainWidget</name>
    <message>
        <location filename="../src/mainwidget.cpp" line="166"/>
        <source>No text recognized</source>
        <translation>هیچ متنی نەدۆزیت</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="214"/>
        <source>Copy text</source>
        <translation>متن کۆپ کەویت</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="221"/>
        <source>Save as TXT</source>
        <translation>بە TXT پارچە کەویت</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="273"/>
        <source>Recognizing</source>
        <translation>دۆزینەویت</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="514"/>
        <source>Copied</source>
        <translation>کۆپ کەویت</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="56"/>
        <source>OCR Tool</source>
        <translation>ئەرەبیکرەویت</translation>
    </message>
</context>
<context>
    <name>ResultTextView</name>
    <message>
        <location filename="../src/resulttextview.cpp" line="15"/>
        <source>Copy</source>
        <translation>کۆپ کەویت</translation>
    </message>
    <message>
        <location filename="../src/resulttextview.cpp" line="17"/>
        <source>Cut</source>
        <translation>پارچە کەویت</translation>
    </message>
    <message>
        <location filename="../src/resulttextview.cpp" line="20"/>
        <source>Select All</source>
        <translation>هەموو نووسەرەویت</translation>
    </message>
    <message>
        <location filename="../src/resulttextview.cpp" line="22"/>
        <source>Paste</source>
        <translation>چاپ کەویت</translation>
    </message>
</context>
<context>
    <name>Widget</name>
    <message>
        <location filename="../src/mainwidget.cpp" line="262"/>
        <source>Tips: The clearer the image is, the more accurate the text is</source>
        <translation>تەپس: ئەگەر وێدەیەک بەتەنەکەریتەوە بەکارهێنریتەوە، متنەکە بەتەنەکەریتەوە بەکارهێنریتەوە</translation>
    </message>
</context>
</TS>
